/*
 * cmdu_validate.h
 * WiFi MultiAP CMDU validation functions header file.
 *
 * Copyright (C) 2020-2022 IOPSYS Software Solutions AB. All rights reserved.
 *
 * See LICENSE file for license related information.
 *
 */

#ifndef CMDU_VALIDATE_H
#define CMDU_VALIDATE_H

#include <cmdu.h>
#include <stddef.h>
#include <stdint.h>

bool validate_channel_scan_report(struct cmdu_buff *cmdu, struct tlv *tv_tsp[][TLV_MAXNUM],
				  struct tlv *tv_scan[], int *num,
				  uint8_t map_profile);

bool validate_topology_response(struct cmdu_buff *cmdu, struct tlv *tlvs[][TLV_MAXNUM],
				size_t tlvs_size, uint8_t map_profile);

bool validate_ap_metric_resp(struct cmdu_buff *cmdu, struct tlv *tlvs[][TLV_MAXNUM],
			     size_t tlvs_size, uint8_t map_profile);

bool validate_ap_cap_report(struct cmdu_buff *cmdu, struct tlv *tlvs[][TLV_MAXNUM],
			    size_t tlvs_size, uint8_t map_profile);

bool validate_bksta_cap_report(struct cmdu_buff *cmdu, struct tlv *tlvs[][TLV_MAXNUM],
			       size_t tlvs_size, uint8_t map_profile);

bool validate_operating_channel_report(struct cmdu_buff *cmdu,
				       struct tlv *tlvs[][TLV_MAXNUM], size_t tlvs_size,
				       uint8_t map_profile);

bool validate_autoconfig_response(struct cmdu_buff *cmdu, struct tlv *tlvs[][TLV_MAXNUM],
				  size_t tlvs_size, uint8_t map_profile);

bool validate_topology_notification(struct cmdu_buff *cmdu, struct tlv *tlvs[][TLV_MAXNUM],
				    size_t tlvs_size, uint8_t map_profile);

bool validate_disassoc_stats(struct cmdu_buff *cmdu, struct tlv *tlvs[][TLV_MAXNUM],
			     size_t tlvs_size, uint8_t map_profile);

bool validate_client_cap_report(struct cmdu_buff *cmdu, struct tlv *tlvs[][TLV_MAXNUM],
				size_t tlvs_size, uint8_t map_profile);

bool validate_unassoc_sta_link_metric_resp(struct cmdu_buff *cmdu, struct tlv *tv[][TLV_MAXNUM],
					   size_t tlvs_size, uint8_t map_profile);

bool validate_channel_preference_report(struct cmdu_buff *cmdu, struct tlv *tv[][TLV_MAXNUM],
					size_t tlvs_size, uint8_t map_profile);

bool validate_link_metric_response(struct cmdu_buff *cmdu, struct tlv *tv[][TLV_MAXNUM],
				   size_t tlvs_size, uint8_t map_profile);

bool validate_anticipated_channel_usage(struct cmdu_buff *cmdu, struct tlv *tlvs[][TLV_MAXNUM],
					size_t tlvs_size, uint8_t map_profile);

#endif	/* CMDU_VALIDATE_H */
