#ifndef UTILS_H
#define UTILS_H

#include <libubox/list.h>
#include <sys/time.h>
#include <stdint.h>


char *get_date(time_t *t, char *tbuf);

/** If t is NULL, get current time and return as null terminated string
 *  e.g.: "2019-02-11T06:42:31-08:00"
 *  If t is not NULL, covert t to formatted string.
 *
 *  Returns timestamp_str.
 */
char *get_timestamp(const time_t *t, char *timestamp_str, size_t size);
void do_daemonize(const char *pidfile);

int getcurrtime(struct timeval *out);
int timeradd_msecs(struct timeval *a, unsigned long msecs, struct timeval *res);


void timestamp_update(struct timespec *ts);
int timestamp_expired(struct timespec *a, unsigned int tmo_ms);
uint32_t timestamp_elapsed_sec(const struct timespec *ts);

size_t list_count(const struct list_head *list);

#ifndef list_flush
#define list_flush(head, type, member)					\
do {									\
	type *__p, *__tmp;						\
									\
	if (!list_empty(head))						\
		list_for_each_entry_safe(__p, __tmp, head, member) {	\
			list_del(&__p->member);				\
			free(__p);					\
		}							\
} while (0)
#endif

#ifndef BIT
#define BIT(n)	(1 << (n))
#endif

#endif /* UTILS_H */
